@@ -2,6 +2,10 @@
 system environment.
 """
 import os
+from typing import Callable
+from typing import Mapping
+from typing import Sequence
+
 from unimatrix.exceptions import ImproperlyConfigured
 
 
@@ -32,7 +36,12 @@ def parsefilepath(environ, key, default=None):
     return fp
 
 
-def parselist(environ, key, sep=':', cls=tuple):
+def parselist(
+    environ: Mapping[str, str],
+    key: str,
+    sep: str = ':',
+    cls: Callable[..., Sequence[str]] = tuple
+) -> Sequence[str]:
     """Parses the environment variable into an iterable,
     using `sep` as a separator e.g.::
 
