@@ -1,10 +1,9 @@
 """Provides an API for date and time related functions."""
 import datetime
-import time
 
 
 def now():
     """Return the current date and time, represented as milliseconds since the
     UNIX epoch.
     """
-    return int(datetime.datetime.utcnow().timestamp() * 1000)
+    return int(datetime.datetime.now(datetime.timezone.utc).timestamp() * 1000)
